[KSplash Theme: Default]
Name = KDE 4.5 Splash Screen
Description = Salix Splash Screen
Version = 2.0
Author = Dimitris Tzemos
Homepage = http://www.salixos.org

# Theme behaviour settings.
Engine = KSplashX
